.. romsearch documentation master file, created by
   sphinx-quickstart on Tue Apr 23 11:38:48 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: intro.rst

.. toctree::
   :titlesonly:
   :maxdepth: 2
   :caption: Documentation

   installation
   gui/intro
   configuration
   1g1r
   modules
   configs
   utils
   known_issues
   changelog
   reference_api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
